@@ -54,13 +54,13 @@ composition_right_horizontal_day_button(WDB *new_day_button){
 
     gtk_widget_set_size_request(new_day_button->box, 70, 177);
     if (new_day_button->background)
-        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->background, 0, 26);
+        gtk_layout_put((new_day_button->box), new_day_button->background, 0, 26);
     if (new_day_button->icon_image)
-        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->icon_image, 0+3, 0);
+        gtk_layout_put((new_day_button->box), new_day_button->icon_image, 0+3, 0);
     if (new_day_button->wind)
-        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind, 0-5+14, 66-9);
+        gtk_layout_put((new_day_button->box), new_day_button->wind, 0-5+14, 66-9);
     if (new_day_button->wind_text)
-        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind_text, 0+14+6, 66+0);
+        gtk_layout_put((new_day_button->box), new_day_button->wind_text, 0+14+6, 66+0);
 
     day = gtk_label_new(NULL);
     day_name = (gchar*)gtk_label_get_text(GTK_LABEL(new_day_button->label));
@@ -102,9 +102,9 @@ composition_right_horizontal_day_button(WDB *new_day_button){
     }
 
     if (day)
-            gtk_fixed_put(GTK_FIXED(new_day_button->box), day, 0, 60+37+10);
+            gtk_layout_put((new_day_button->box), day, 0, 60+37+10);
     if (temperature)
-            gtk_fixed_put(GTK_FIXED(new_day_button->box), temperature, 0+2, 60+37+9+30);
+            gtk_layout_put((new_day_button->box), temperature, 0+2, 60+37+9+30);
 
     gtk_widget_destroy(new_day_button->label);
 #ifdef DEBUGFUNCTIONCALL
@@ -136,13 +136,13 @@ composition_central_horizontal_day_button(WDB *new_day_button)
 
     gtk_widget_set_size_request(new_day_button->box, 70, 177);
     if (new_day_button->background)
-        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->background, 0, 26);
+        gtk_layout_put((new_day_button->box), new_day_button->background, 0, 26);
     if (new_day_button->icon_image)
-        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->icon_image, 0+3, 0);
+        gtk_layout_put((new_day_button->box), new_day_button->icon_image, 0+3, 0);
     if (new_day_button->wind)
-        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind, 0-5+14, 66-9);
+        gtk_layout_put((new_day_button->box), new_day_button->wind, 0-5+14, 66-9);
     if (new_day_button->wind_text)
-        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind_text, 0+14+6, 66+0);
+        gtk_layout_put((new_day_button->box), new_day_button->wind_text, 0+14+6, 66+0);
 
     day = gtk_label_new(NULL);
     day_name = (gchar*)gtk_label_get_text(GTK_LABEL(new_day_button->label));
@@ -182,9 +182,9 @@ composition_central_horizontal_day_button(WDB *new_day_button)
     gtk_widget_set_size_request(temperature, 66, 60);
 
     if (day)
-            gtk_fixed_put(GTK_FIXED(new_day_button->box), day, 0, 60+37+10);
+            gtk_layout_put((new_day_button->box), day, 0, 60+37+10);
     if (temperature)
-            gtk_fixed_put(GTK_FIXED(new_day_button->box), temperature, 0+2, 60+37+9+30);
+            gtk_layout_put((new_day_button->box), temperature, 0+2, 60+37+9+30);
 
     gtk_widget_destroy(new_day_button->label);
 #ifdef DEBUGFUNCTIONCALL
@@ -216,13 +216,13 @@ composition_central_vertical_day_button(WDB *new_day_button)
 
     gtk_widget_set_size_request(new_day_button->box, 70, 200);
     if (new_day_button->background)
-        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->background, 0, 0);
+        gtk_layout_put((new_day_button->box), new_day_button->background, 0, 0);
     if (new_day_button->icon_image)
-        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->icon_image, 0+3, 2);
+        gtk_layout_put((new_day_button->box), new_day_button->icon_image, 0+3, 2);
     if (new_day_button->wind)
-        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind, 0-5+14, 66-4);
+        gtk_layout_put((new_day_button->box), new_day_button->wind, 0-5+14, 66-4);
     if (new_day_button->wind_text)
-        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind_text, 0+14+6, 66+5);
+        gtk_layout_put((new_day_button->box), new_day_button->wind_text, 0+14+6, 66+5);
 
     day = gtk_label_new(NULL);
     day_name = (gchar*)gtk_label_get_text(GTK_LABEL(new_day_button->label));
@@ -262,9 +262,9 @@ composition_central_vertical_day_button(WDB *new_day_button)
     gtk_widget_set_size_request(temperature, 66, 60);
 
     if (day)
-            gtk_fixed_put(GTK_FIXED(new_day_button->box), day, 0, 60+37+17-2);
+            gtk_layout_put((new_day_button->box), day, 0, 60+37+17-2);
     if (temperature)
-            gtk_fixed_put(GTK_FIXED(new_day_button->box), temperature, 0+2, 60+37+16+30-5 );
+            gtk_layout_put((new_day_button->box), temperature, 0+2, 60+37+16+30-5 );
 
     gtk_widget_destroy(new_day_button->label);
 #ifdef DEBUGFUNCTIONCALL
@@ -335,33 +335,33 @@ composition_left_vertical_day_button(WDB *new_day_button, gint layout)
         case PRESET_NOW_PLUS_TWO:
             gtk_widget_set_size_request(new_day_button->box, 70, 200);
             if (new_day_button->background)
-                gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->background, 12+15-6, 0);
+                gtk_layout_put((new_day_button->box), new_day_button->background, 12+15-6, 0);
             if (new_day_button->icon_image)
-                gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->icon_image, 12+15-6+3, 2);
+                gtk_layout_put((new_day_button->box), new_day_button->icon_image, 12+15-6+3, 2);
             if (new_day_button->wind)
-                gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind, 12+15-10+14, 66-4);
+                gtk_layout_put((new_day_button->box), new_day_button->wind, 12+15-10+14, 66-4);
             if (new_day_button->wind_text)
-                gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind_text, 12+15-6+14+6, 66+5);
+                gtk_layout_put((new_day_button->box), new_day_button->wind_text, 12+15-6+14+6, 66+5);
             if (day)
-                    gtk_fixed_put(GTK_FIXED(new_day_button->box), day, 12+15, 60+37+17-2);
+                    gtk_layout_put((new_day_button->box), day, 12+15, 60+37+17-2);
             if (temperature)
-                    gtk_fixed_put(GTK_FIXED(new_day_button->box), temperature, 12+15+2, 60+37+16+30-5);
+                    gtk_layout_put((new_day_button->box), temperature, 12+15+2, 60+37+16+30-5);
             break;
         default:
         case PRESET_NOW_PLUS_THREE_V:
             gtk_widget_set_size_request(new_day_button->box, 70, 200);
             if (new_day_button->background)
-                gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->background, 0, 0);
+                gtk_layout_put((new_day_button->box), new_day_button->background, 0, 0);
             if (new_day_button->icon_image)
-                gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->icon_image, 0+3, 2);
+                gtk_layout_put((new_day_button->box), new_day_button->icon_image, 0+3, 2);
             if (new_day_button->wind)
-                gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind, 0-5+14, 66-4);
+                gtk_layout_put((new_day_button->box), new_day_button->wind, 0-5+14, 66-4);
             if (new_day_button->wind_text)
-                gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind_text, 0+14+6, 66+5);
+                gtk_layout_put((new_day_button->box), new_day_button->wind_text, 0+14+6, 66+5);
             if (day)
-                    gtk_fixed_put(GTK_FIXED(new_day_button->box), day, 0, 60+37+17-2);
+                    gtk_layout_put((new_day_button->box), day, 0, 60+37+17-2);
             if (temperature)
-                    gtk_fixed_put(GTK_FIXED(new_day_button->box), temperature, 0+2, 60+37+16+30-5);
+                    gtk_layout_put((new_day_button->box), temperature, 0+2, 60+37+16+30-5);
             break;
     }
 
@@ -431,32 +431,32 @@ composition_right_vertical_day_button(WDB *new_day_button, gint layout)
     switch (layout){
         case PRESET_NOW_PLUS_TWO:
             if (new_day_button->background)
-                gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->background, 7, 0);
+                gtk_layout_put((new_day_button->box), new_day_button->background, 7, 0);
             if (new_day_button->icon_image)
-                gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->icon_image, 7+3, 2);
+                gtk_layout_put((new_day_button->box), new_day_button->icon_image, 7+3, 2);
             if (new_day_button->wind)
-                gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind, 7-5+14, 66-4);
+                gtk_layout_put((new_day_button->box), new_day_button->wind, 7-5+14, 66-4);
             if (new_day_button->wind_text)
-                gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind_text, 7+14+6, 66+5); 
+                gtk_layout_put((new_day_button->box), new_day_button->wind_text, 7+14+6, 66+5); 
             if (day)
-                gtk_fixed_put(GTK_FIXED(new_day_button->box), day, 0+8, 60+37+17-2);
+                gtk_layout_put((new_day_button->box), day, 0+8, 60+37+17-2);
             if (temperature)
-                gtk_fixed_put(GTK_FIXED(new_day_button->box), temperature, 0+8+2, 60+37+16+30-5);
+                gtk_layout_put((new_day_button->box), temperature, 0+8+2, 60+37+16+30-5);
             break;
         default:
         case PRESET_NOW_PLUS_THREE_V:
             if (new_day_button->background)
-                gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->background, 0, 0);
+                gtk_layout_put((new_day_button->box), new_day_button->background, 0, 0);
             if (new_day_button->icon_image)
-                gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->icon_image, 0+3, 2);
+                gtk_layout_put((new_day_button->box), new_day_button->icon_image, 0+3, 2);
             if (new_day_button->wind)
-                gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind, 0-5+14, 66-4);
+                gtk_layout_put((new_day_button->box), new_day_button->wind, 0-5+14, 66-4);
             if (new_day_button->wind_text)
-                gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind_text, 0+14+6, 66+5); 
+                gtk_layout_put((new_day_button->box), new_day_button->wind_text, 0+14+6, 66+5); 
             if (day)
-                gtk_fixed_put(GTK_FIXED(new_day_button->box), day, 0+1, 60+37+17-2);
+                gtk_layout_put((new_day_button->box), day, 0+1, 60+37+17-2);
             if (temperature)
-                gtk_fixed_put(GTK_FIXED(new_day_button->box), temperature, 0+1+2, 60+37+16+30-5);
+                gtk_layout_put((new_day_button->box), temperature, 0+1+2, 60+37+16+30-5);
             break;
     }
 
@@ -509,22 +509,22 @@ composition_now(WDB *new_day_button, gint layout)
     new_day_button->background = gtk_image_new_from_file (buffer);
 /* Packing all to the box */
     if (new_day_button->background)
-//        gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->background, xoffset, 37+15);
+//        gtk_layout_put((new_day_button->box), new_day_button->background, xoffset, 37+15);
         gtk_layout_put((new_day_button->box), new_day_button->background, xoffset, 37+15);
     if (new_day_button->icon_image)
- //       gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->icon_image, 0+image_xoffset, 0);
+ //       gtk_layout_put((new_day_button->box), new_day_button->icon_image, 0+image_xoffset, 0);
         gtk_layout_put((new_day_button->box), new_day_button->icon_image, 0+image_xoffset, 0);
     if (new_day_button->wind)
-    //    gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind, (87+14) + xoffset + wind_xoffset - 11, 5+37+10);
+    //    gtk_layout_put((new_day_button->box), new_day_button->wind, (87+14) + xoffset + wind_xoffset - 11, 5+37+10);
         gtk_layout_put((new_day_button->box), new_day_button->wind, (87+14) + xoffset + wind_xoffset - 11, 5+37+10);
     if (new_day_button->wind_text)
-  //      gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->wind_text, (87+14) + xoffset + wind_xoffset, 7+37+18+1);
+  //      gtk_layout_put((new_day_button->box), new_day_button->wind_text, (87+14) + xoffset + wind_xoffset, 7+37+18+1);
         gtk_layout_put((new_day_button->box), new_day_button->wind_text, (87+14) + xoffset + wind_xoffset, 7+37+18+1);
     if (new_day_button->shadow_label)
-      //  gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->shadow_label, xoffset+2, 60+37+15+2);
+      //  gtk_layout_put((new_day_button->box), new_day_button->shadow_label, xoffset+2, 60+37+15+2);
         gtk_layout_put((new_day_button->box), new_day_button->shadow_label, xoffset+2, 60+37+15+2);
     if (new_day_button->label)
-      //  gtk_fixed_put(GTK_FIXED(new_day_button->box), new_day_button->label, xoffset, 60+37+15);
+      //  gtk_layout_put((new_day_button->box), new_day_button->label, xoffset, 60+37+15);
         gtk_layout_put((new_day_button->box), new_day_button->label, xoffset, 60+37+15);
 #ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
@@ -550,11 +550,14 @@ realize (GtkWidget *widget)
     pixbuf=gdk_pixbuf_new_from_file("/usr/share/omweather/button_icons/nothing.png",&error);
     scaled=gdk_pixbuf_scale_simple(pixbuf,700,700, GDK_INTERP_BILINEAR);
     g_object_unref(G_OBJECT(pixbuf));
+//    scaled=gdk_pixbuf_new_from_file("/usr/share/omweather/button_icons/nothing.png",&error);
     gdk_pixbuf_render_pixmap_and_mask_for_colormap(scaled,colormap,&background,NULL,0);
     g_object_unref(G_OBJECT(scaled));
     style = gtk_style_new();
     style->bg_pixmap[0] = background;
     gtk_widget_set_style(GTK_WIDGET(widget),GTK_STYLE(style));
+    g_object_unref (G_OBJECT (style));
+
 }
    
 /*******************************************************************************/
@@ -588,7 +591,7 @@ next_station_preset_now(gint layout)
             snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_NOW_BACKGROUND_TOWN_HORIZONTAL);
             background_town = gtk_image_new_from_file (buffer);
             if (background_town)
-     //           gtk_fixed_put(GTK_FIXED(widget), background_town, 12+15, 0);
+     //           gtk_layout_put((widget), background_town, 12+15, 0);
                 gtk_layout_put((widget), background_town, 12+15, 0);
             x_width = 138;
             x_offset = 12+15;
@@ -597,7 +600,7 @@ next_station_preset_now(gint layout)
             snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_NOW_BACKGROUND_TOWN_PLUS_TWO);
             background_town = gtk_image_new_from_file (buffer);
             if (background_town)
-         //       gtk_fixed_put(GTK_FIXED(widget), background_town, 12+15, 0);
+         //       gtk_layout_put((widget), background_town, 12+15, 0);
                 gtk_layout_put((widget), background_town, 12+15, 0);
             x_width = 140;
             x_offset = 12+15;
@@ -606,8 +609,8 @@ next_station_preset_now(gint layout)
             snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_NOW_BACKGROUND_TOWN_PLUS_THREE_V);
             background_town = gtk_image_new_from_file (buffer);
             if (background_town)
-//                gtk_fixed_put(GTK_FIXED(widget), background_town, 0, 0);
-                gtk_layout_put(GTK_FIXED(widget), background_town, 0, 0);
+//                gtk_layout_put((widget), background_town, 0, 0);
+                gtk_layout_put((widget), background_town, 0, 0);
             x_width = 210;
             x_offset = 0;
             break;
@@ -616,7 +619,7 @@ next_station_preset_now(gint layout)
             snprintf(buffer, sizeof(buffer) - 1, "%s%s", IMAGES_PATH, PRESET_NOW_BACKGROUND_TOWN);
             background_town = gtk_image_new_from_file (buffer);
             if (background_town)
-//                gtk_fixed_put(GTK_FIXED(widget), background_town, 12+15, 0);
+//                gtk_layout_put((widget), background_town, 12+15, 0);
                 gtk_layout_put((widget), background_town, 12+15, 0);
             x_width = 140;
             x_offset = 12+15;
@@ -660,14 +663,14 @@ next_station_preset_now(gint layout)
     }
 
     if (station_name_btn)
-//        gtk_fixed_put(GTK_FIXED(widget), station_name_btn, x_offset, 0);
+//        gtk_layout_put((widget), station_name_btn, x_offset, 0);
         gtk_layout_put((widget), station_name_btn, x_offset, 0);
     gtk_widget_show(station_name_btn);
     if (shadow_station_text)
-//        gtk_fixed_put(GTK_FIXED(widget), shadow_station_text, x_offset+2+1, 17+1);
+//        gtk_layout_put((widget), shadow_station_text, x_offset+2+1, 17+1);
         gtk_layout_put((widget), shadow_station_text, x_offset+2+1, 17+1);
     if (station_text)
-//        gtk_fixed_put(GTK_FIXED(widget), station_text, x_offset+1+1,17);
+//        gtk_layout_put((widget), station_text, x_offset+1+1,17);
         gtk_layout_put((widget), station_text, x_offset+1+1,17);
 #ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
@@ -785,7 +788,10 @@ fill_weather_day_button_presets(WDB *new_day_button, const char *text, const cha
         else
             new_day_button->wind = NULL;
     }
-    new_day_button->box  = gtk_fixed_new();
+  //  new_day_button->box  = gtk_fixed_new();
+    new_day_button->box  = gtk_layout_new(NULL, NULL);
+    realize(new_day_button->box);
+    gtk_widget_set_size_request(new_day_button->box, 1, 4);
 //#ifdef DEBUGFUNCTIONCALL
     END_FUNCTION;
 //#endif
